@@ -29,6 +29,7 @@
 #include <bonobo/bonobo-ui-main.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <libgnomevfs/gnome-vfs-monitor.h>
+#include <libgnomevfs/gnome-vfs-ops.h>
 
 #include <math.h>
 #include <ctype.h>
@@ -518,7 +519,8 @@ verb_HelpAbout(BonoboUIComponent * uic, gpointer data, const char *cname)
   static GtkWidget *about = NULL;
   static gboolean translated = FALSE;
   static const char *authors[] = {
-    N_("Jaka Mocnik (current maintainer)"),
+    N_("Gary Ekker (current maintainer)"),
+    "Jaka Mocnik",
     "Jonathan Blandford",
     "Daniel M. German",
     "Satyajit Kanungo",
@@ -694,7 +696,7 @@ static void
 ggv_window_destroy(GtkObject * object)
 {
   GgvWindow *win;
-  gint i, w, h;
+  gint w, h;
 
   g_return_if_fail(object != NULL);
   g_return_if_fail(GGV_IS_WINDOW(object));
@@ -963,6 +965,7 @@ ggv_file_open_recent(EggRecentView * view, EggRecentItem * item, gpointer data)
   return TRUE;
 }
 
+void
 ggv_add_open_button(GgvWindow * win, BonoboUIComponent * ui_component,
                     const gchar * path, const gchar * tooltip)
 {
