@@ -1863,8 +1863,6 @@ gtk_gs_get_page_count(GtkGS * gs)
 gboolean
 gtk_gs_goto_page(GtkGS * gs, gint page)
 {
-  struct stat sbuf;
-
   g_return_val_if_fail(gs != NULL, FALSE);
   g_return_val_if_fail(GTK_IS_GS(gs), FALSE);
 
@@ -1888,7 +1886,7 @@ gtk_gs_goto_page(GtkGS * gs, gint page)
     if(!GTK_WIDGET_REALIZED(gs))
       return FALSE;
 
-    if(gs->doc->pages[page].orientation != NONE &&
+    if(gs->doc->pages[page].orientation != GTK_GS_ORIENTATION_NONE &&
        !gs->override_orientation &&
        gs->doc->pages[page].orientation != gs->real_orientation) {
       gs->real_orientation = gs->doc->pages[page].orientation;
